@@ -2,7 +2,6 @@ import logging
 from laboro.error import LaboroError
 from laboro.module import Module
 from laboro_database.connector.pgsql import DbPgsql
-from laboro_database.connector.oracle import DbOracle
 from laboro_database.connector.sqlite3 import DbSqlite3
 from laboro_database.connector.mysql import DbMysql
 
@@ -21,14 +20,13 @@ class Database(Module):
       ``port``: Int. Optional.
       ``service``: String. A PostgresSQL service name. Optional.
       ``database``: The database name. Mandatory.
-      ``db_type``: String, one of `postgres`, `oracle`, `sqlite3`, `mysql`. Mandatory.
+      ``db_type``: String, one of `postgres`, `sqlite3`, `mysql`. Mandatory.
 
   """
 
   def __init__(self, context, args=None):
     super().__init__(filepath=__file__, context=context, args=args)
     self.connectors = {"pgsql": DbPgsql,
-                       "oracle": DbOracle,
                        "sqlite3": DbSqlite3,
                        "mysql": DbMysql}
     self.connector = None
@@ -58,7 +56,7 @@ class Database(Module):
 
   @Module.laboro_method
   def query(self, request, params=None, commit=False,
-            verbose=False, exit_on_error=False):
+            verbose=False, exit_on_error=True):
     """Prepare and execute the specified query on the database.
     In conformance to `Python Database API v2.0` (See https://peps.python.org/pep-0249), parameters may be provided as sequence or mapping and will be bound to variables in the operation. If error occurs while request execution, the request will be `rollbacked`.
 
@@ -66,8 +64,8 @@ class Database(Module):
       ``request``: String. The SQL request to execute. The string request should use the `named paramstyle` (see https://peps.python.org/pep-0249/#paramstyle)v for parameters mapping.
       ``params``: An optional dictionary specifying the needed parameters to be mapped on the ``request`` string.
       ``commit``: Boolean. When set to `True`, a commit statement will be sent to the database immediately after the request execution.
-      ``verbose``: Boolean. If set to `True`, request, parameters and result will be sent to the logger.
-      ``exit_on_error``: Boolean. If set to `True`, any error encountered while request execution will raise an error and exit the workflow after query rollback.
+      ``verbose``: Boolean. If set to `True`, request, parameters and result will be sent to the logger. Default to ``False``
+      ``exit_on_error``: Boolean. If set to `True`, any error encountered while request execution will raise an error and exit the workflow after query rollback. Default to ``True``.
 
     Returns:
       A database ``cursor`` containing the returned values.
@@ -90,7 +88,7 @@ class Database(Module):
         logging.error("Rollbacking...")
         self.connection.rollback()
         if exit_on_error:
-          raise LaboroError(f"DatabaseQueryError: An error occurred while querying the database: {err}") from err
+          raise LaboroError(f"[DatabaseQueryError] An error occurred while querying the database: {err}") from err
 
   @Module.laboro_method
   def multi_query(self, request, paramlist, commit=False,
@@ -124,7 +122,7 @@ class Database(Module):
         logging.error("Rollbacking...")
         self.connection.rollback()
         if exit_on_error:
-          raise LaboroError(f"DatabaseQueryError: An error occurred while querying the database: {err}") from err
+          raise LaboroError(f"[DatabaseQueryError] An error occurred while querying the database: {err}") from err
 
   @Module.laboro_method
   def transaction(self, requests, verbose=False, exit_on_error=False):
@@ -158,4 +156,4 @@ class Database(Module):
         logging.error("Rollbacking...")
         self.connection.rollback()
         if exit_on_error:
-          raise LaboroError(f"DatabaseQueryError: An error occurred while querying the database: {err}") from err
+          raise LaboroError(f"[DatabaseQueryError] An error occurred while querying the database: {err}") from err
