@@ -1,6 +1,8 @@
 import logging
 import mysql.connector
 
+logger = logging.getLogger("laboro.main")
+
 
 class DbMysql:
 
@@ -20,8 +22,8 @@ class DbMysql:
   @staticmethod
   def query(cursor, request, params=None, verbose=False):
     if verbose:
-      logging.info(f"Request: {request}")
-      logging.info(f"Params: {params}")
+      logger.info(f"Request: {request}")
+      logger.info(f"Params: {params}")
     if params is not None:
       cursor.execute(request, params)
     else:
@@ -29,5 +31,5 @@ class DbMysql:
     rows = cursor.fetchall()
     if verbose:
       for row in rows:
-        logging.info(f"{' | '.join([str(i) for i in row])}")
+        logger.info(f"{' | '.join([str(i) for i in row])}")
     return rows
