@@ -1,6 +1,8 @@
 import logging
 import cx_Oracle
 
+logger = logging.getLogger("laboro.main")
+
 
 class DbOracle:
 
@@ -17,8 +19,8 @@ class DbOracle:
   @staticmethod
   def query(cursor, request, params=None, verbose=False):
     if verbose:
-      logging.info(f"Request: {request}")
-      logging.info(f"Params: {params}")
+      logger.info(f"Request: {request}")
+      logger.info(f"Params: {params}")
     if params is not None:
       cursor.execute(request, params)
     else:
@@ -27,7 +29,7 @@ class DbOracle:
       rows = cursor.fetchall()
       if verbose:
         for row in rows:
-          logging.info(f"{' | '.join([str(i) for i in row])}")
+          logger.info(f"{' | '.join([str(i) for i in row])}")
       return rows
     except cx_Oracle.InterfaceError:
       return list()
