@@ -1,6 +1,8 @@
 import logging
 import psycopg2
 
+logger = logging.getLogger("laboro.main")
+
 
 class DbPgsql:
 
@@ -22,8 +24,8 @@ class DbPgsql:
   @staticmethod
   def query(cursor, request, params=None, verbose=False):
     if verbose:
-      logging.info(f"Request: {request}")
-      logging.info(f"Params: {params}")
+      logger.info(f"Request: {request}")
+      logger.info(f"Params: {params}")
     if params is not None:
       cursor.execute(request, params)
     else:
@@ -32,7 +34,7 @@ class DbPgsql:
       rows = cursor.fetchall()
       if verbose:
         for row in rows:
-          logging.info(f"{' | '.join([str(i) for i in row])}")
+          logger.info(f"{' | '.join([str(i) for i in row])}")
       return rows
     except psycopg2.ProgrammingError:
       return list()
