@@ -1,6 +1,8 @@
 import logging
 import sqlite3
 
+logger = logging.getLogger("laboro.main")
+
 
 class DbSqlite3:
 
@@ -16,8 +18,8 @@ class DbSqlite3:
   @staticmethod
   def query(cursor, request, params=None, verbose=False):
     if verbose:
-      logging.info(f"Request: {request}")
-      logging.info(f"Params: {params}")
+      logger.info(f"Request: {request}")
+      logger.info(f"Params: {params}")
     if params is not None:
       cursor.execute(request, params)
     else:
@@ -25,5 +27,5 @@ class DbSqlite3:
     rows = cursor.fetchall()
     if verbose:
       for row in rows:
-        logging.info(f"{' | '.join([str(i) for i in row])}")
+        logger.info(f"{' | '.join([str(i) for i in row])}")
     return rows
